using System;
using Foundation;
using UIKit;
using Photos;
using CoreGraphics;
using System.Linq;

namespace VJ
{
	public class MyImageView : UIImageView
	{
		PHAssetCollection _album;
		PHAsset[] _assets;
		PHImageRequestOptions _options = new PHImageRequestOptions();
		ViewController _controller;
		int _preIndex = -2;

		public MyImageView(ViewController controller)
		{
			_controller = controller;
			_options.Version = PHImageRequestOptionsVersion.Current;
			_options.ResizeMode = PHImageRequestOptionsResizeMode.Fast;
			_options.DeliveryMode = PHImageRequestOptionsDeliveryMode.FastFormat;
			_options.NetworkAccessAllowed = true;
			_options.Synchronous = false;
		}

		public void ReadImage(CGRect bounds)
		{
			UserInteractionEnabled = true;
			Bounds = bounds;
			Frame = bounds;
			_album = GetMyAlbum();
			if (_album == null) return;
			_assets = PHAsset.FetchAssets(_album, null)
							 .Cast<PHAsset>()
							 .ToArray();
			RandomImage();
		}

		PHAssetCollection GetMyAlbum()
		{
			var assetCollections =
				PHAssetCollection.FetchAssetCollections(PHAssetCollectionType.SmartAlbum,
														PHAssetCollectionSubtype.SmartAlbumUserLibrary,
														null);
			if (assetCollections.Count == 0)
			{
				assetCollections =
				PHAssetCollection.FetchAssetCollections(PHAssetCollectionType.Album,
														PHAssetCollectionSubtype.SmartAlbumUserLibrary,
														null);
			}
			return assetCollections.OfType<PHAssetCollection>()
								   .FirstOrDefault();
		}

		public void RandomImage()
		{
			if (_album == null || _assets.Length == 0) return;
			var index = new Random().Next(0, _assets.Length);
			while (_preIndex == index)
			{
				index = new Random().Next(0, _assets.Length);
			}
			UpdateImage(_assets[index]);
			_preIndex = index;
		}

		public void UpdateImage(PHAsset asset)
		{
			PHImageManager.DefaultManager
						  .RequestImageForAsset(asset,
												new CGSize(Bounds.Width, Bounds.Height),
												PHImageContentMode.Default,
												_options,
												(result, info) => { if (result != null) Image = result; });
		}

		public override void TouchesBegan(NSSet touches, UIEvent evt)
		{
			base.TouchesBegan(touches, evt);
			_controller.PlaySound();
		}
	}
}
